@@ -479,23 +479,23 @@ bool ScanWidget::createPipe( const TQString type, const TQString& tempDir, TQFil
 		delete pipe;
 	}
 
-	if( mkfifo( pipe->name( ), 0600 ))
+	if( mkfifo( pipe->name( ).local8Bit(), 0600 ))
 	{	TQString text = TQString( i18n( "Couldn't create the named pipe \"%1\" for nmap output: %2\n" )).arg( pipe->name( )).arg( strerror( errno ));
-		m_outputWidget->addOutput( OutputWidget::Stderr, text, text.length( ));
+		m_outputWidget->addOutput( OutputWidget::Stderr, text.local8Bit(), text.local8Bit().length( ));
 
 		delete pipe;
 		pipe = NULL;
 		return false;
 	}
 
-	pipeFD = ::open( pipe->name( ), O_RDONLY | O_NONBLOCK );
+	pipeFD = ::open( pipe->name( ).local8Bit(), O_RDONLY | O_NONBLOCK );
 
 	if( pipeFD != -1 )
 		return true;
 
 	TQString text = TQString( i18n( "Couldn't open the named pipe \"%1\" for nmap output: %2\n" )).arg( pipe->name( ))
 																								.arg( strerror( errno ));
-	m_outputWidget->addOutput( OutputWidget::Stderr, text, text.length( ));
+	m_outputWidget->addOutput( OutputWidget::Stderr, text.local8Bit(), text.local8Bit().length( ));
 
 	delete pipe;
 	pipe = NULL;
@@ -506,15 +506,15 @@ bool ScanWidget::createPipe( const TQString type, const TQString& tempDir, TQFil
 //	===========
 
 bool ScanWidget::createPipes( )
-{	ASSERT( m_pipeStderr == NULL );
-	ASSERT( m_pipeStdout == NULL );
+{	Q_ASSERT( m_pipeStderr == NULL );
+	Q_ASSERT( m_pipeStdout == NULL );
 
 	TDEStandardDirs standardDirs;
 	TQStringList tempDir = standardDirs.resourceDirs( "tmp" );
 
 	if( tempDir.isEmpty( ))
 	{	TQString text = TQString( i18n( "Couldn't create the named pipe for nmap output: no temp file dir\n" ));
-		m_outputWidget->addOutput( OutputWidget::Stderr, text, text.length( ));
+		m_outputWidget->addOutput( OutputWidget::Stderr, text.local8Bit(), text.local8Bit().length( ));
 		return false;
 	}
 
@@ -593,7 +593,7 @@ bool ScanWidget::getOptions( )
 		return false;
 
 	if( m_commonWidget->host( ).isEmpty( ) && !m_compoundWidget->targetFileState( ))
-	{	KMessageBox::error( this, i18n( TQString( "Target host(s) not specified by \"Target host(s)\" or \"Target hosts file\" options" )), i18n( "Target host(s) error" ));
+	{	KMessageBox::error( this, i18n( "Target host(s) not specified by \"Target host(s)\" or \"Target hosts file\" options" ), i18n( "Target host(s) error" ));
 		return false;
 	}
 
@@ -983,7 +983,7 @@ void ScanWidget::slotStartClicked( )
 
 	cmd.stripWhiteSpace( );
 	m_clearOutputButton->setEnabled( true );
-	m_outputWidget->addOutput( OutputWidget::Stdin, cmd, cmd.length( ));
+	m_outputWidget->addOutput( OutputWidget::Stdin, cmd.local8Bit(), cmd.local8Bit().length( ));
 
 	emit( outputAvailable( true, true ));
 	connect( m_nmapProcess, SIGNAL( processExited( TDEProcess* )), SLOT( slotProcessExited( )));
@@ -1059,3 +1059,5 @@ void ScanWidget::useTargetHost( const bool b )
 void ScanWidget::wrapText( const bool wrap )
 {	m_outputWidget->setWordWrap( wrap ? TQTextEdit::WidgetWidth : TQTextEdit::NoWrap );
 }
+
+#include "scanwidget.moc"
